@@ -132,7 +132,7 @@ void FileMetaDataConfigWidget::Private::slotLoadingFinished()
     // Always show these 3
     data.remove("rating");
     data.remove("tags");
-    data.remove("userComment");
+    data.remove("comment");
 
     QVariantMap::const_iterator it = data.constBegin();
     while (it != data.constEnd()) {
@@ -142,7 +142,7 @@ void FileMetaDataConfigWidget::Private::slotLoadingFinished()
 
     addItem("rating");
     addItem("tags");
-    addItem("userComment");
+    addItem("comment");
 }
 
 FileMetaDataConfigWidget::FileMetaDataConfigWidget(QWidget* parent) :
