@@ -2,7 +2,7 @@
     <one line to give the library's name and an idea of what it does.>
     Copyright (C) 2012-2013  Vishesh Handa <me@vhanda.in>
 
-    Adapted from KFileMetadataWidget
+    Adapated from KFileMetadataWidget
     Copyright (C) 2008 by Sebastian Trueg <trueg@kde.org>
     Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>
 
@@ -26,22 +26,18 @@
 #include "widgetfactory.h"
 #include "filemetadataprovider.h"
 
-#include <KConfig>
-#include <KConfigGroup>
-
 #include <KFileItem>
 #include <KFileMetaData/UserMetaData>
 
-#include <QCheckBox>
-#include <QGridLayout>
-#include <QLabel>
-#include <QSpacerItem>
-#include <QList>
-#include <QSet>
-#include <QString>
-#include <QTimer>
-#include <QFileInfo>
-#include <QDebug>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QSpacerItem>
+#include <QtCore/QList>
+#include <QtCore/QSet>
+#include <QtCore/QString>
+#include <QtCore/QTimer>
+#include <QtCore/QFileInfo>
+#include <QtCore/QDebug>
 
 using namespace Baloo;
 
@@ -50,7 +46,6 @@ class Baloo::FileMetaDataWidget::Private
 public:
     struct Row
     {
-        QCheckBox* checkBox;
         QLabel* label;
         QWidget* value;
     };
@@ -58,6 +53,13 @@ public:
     Private(FileMetaDataWidget* parent);
     ~Private();
 
+    /**
+     * Parses the configuration file "kmetainformationrc" and
+     * updates the visibility of all rows that got their data
+     * from KFileItem.
+     */
+    void updateFileItemRowsVisibility();
+
     void deleteRows();
 
     void slotLoadingFinished();
@@ -66,9 +68,6 @@ public:
     void slotDataChangeFinished();
 
     QStringList sortedKeys(const QVariantMap& data) const;
-    QLabel* createLabel(const QString &key,  const QString& itemLabel, FileMetaDataWidget* parent);
-
-    void saveConfig();
 
     QList<Row> m_rows;
     FileMetaDataProvider* m_provider;
@@ -77,17 +76,14 @@ public:
     MetadataFilter* m_filter;
     WidgetFactory* m_widgetFactory;
 
-    QMap<QString, bool> m_visibilityChanged;
-    bool m_configureVisibleProperties = false;
-
 private:
     FileMetaDataWidget* const q;
 };
 
 FileMetaDataWidget::Private::Private(FileMetaDataWidget* parent)
     : m_rows()
-    , m_provider(nullptr)
-    , m_gridLayout(nullptr)
+    , m_provider(0)
+    , m_gridLayout(0)
     , q(parent)
 {
     m_filter = new MetadataFilter(q);
@@ -98,7 +94,7 @@ FileMetaDataWidget::Private::Private(FileMetaDataWidget* parent)
     // TODO: If KFileMetaDataProvider might get a public class in future KDE releases,
     // the following code should be moved into KFileMetaDataWidget::setModel():
     m_provider = new FileMetaDataProvider(q);
-    connect(m_provider, &FileMetaDataProvider::loadingFinished, q, [this](){ slotLoadingFinished(); });
+    connect(m_provider, SIGNAL(loadingFinished()), q, SLOT(slotLoadingFinished()));
 }
 
 FileMetaDataWidget::Private::~Private()
@@ -107,112 +103,63 @@ FileMetaDataWidget::Private::~Private()
 
 void FileMetaDataWidget::Private::deleteRows()
 {
-    for (const Row& row : qAsConst(m_rows)) {
+    foreach (const Row& row, m_rows) {
         delete row.label;
         row.value->deleteLater();
-        if (row.checkBox) {
-            row.checkBox->deleteLater();
-        }
     }
 
     m_rows.clear();
 }
 
-QLabel* FileMetaDataWidget::Private::createLabel(const QString &key, const QString& itemLabel, FileMetaDataWidget* parent)
-{
-    QLabel* label = new QLabel(itemLabel + QLatin1Char(':'), parent);
-    label->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
-    label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
-    label->setForegroundRole(parent->foregroundRole());
-    label->setFont(parent->font());
-    label->setWordWrap(true);
-    label->setAlignment(Qt::AlignTop | Qt::AlignRight);
-    label->setObjectName(QStringLiteral("L_%1").arg(key));
-    return label;
-}
-
 void FileMetaDataWidget::Private::slotLoadingFinished()
 {
     deleteRows();
 
-    if (m_gridLayout == nullptr) {
+    if (m_gridLayout == 0) {
         m_gridLayout = new QGridLayout(q);
-        m_gridLayout->setContentsMargins(0, 0, 0, 0);
+        m_gridLayout->setMargin(0);
         m_gridLayout->setSpacing(q->fontMetrics().height() / 4);
     }
 
-    QVariantMap data = m_provider->data();
-    QStringList active;
-    if (m_configureVisibleProperties) {
-        active = m_filter->filter(data).keys();
-        auto changedIt = m_visibilityChanged.constBegin();
-        while (changedIt != m_visibilityChanged.constEnd()) {
-            if (changedIt.value()) {
-                active.append(changedIt.key());
-            } else {
-                active.removeAll(changedIt.key());
-            }
-            changedIt++;
-        }
-        m_widgetFactory->setNoLinks(true);
-        m_widgetFactory->setReadOnly(true);
-        m_gridLayout->setColumnStretch(0, 1);
-        m_gridLayout->setColumnStretch(1, 3);
-        m_gridLayout->setColumnStretch(2, 0);
-        m_gridLayout->setColumnStretch(3, 6);
-    } else {
-        data = m_filter->filter(data);
-        m_widgetFactory->setNoLinks( m_provider->realTimeIndexing() );
-        m_widgetFactory->setReadOnly(m_provider->isReadOnly());
-        m_gridLayout->setColumnStretch(0, 4);
-        m_gridLayout->setColumnStretch(1, 0);
-        m_gridLayout->setColumnStretch(2, 6);
-        m_gridLayout->setColumnStretch(3, 0);
-    }
+    // Filter the data
+    QVariantMap data = m_filter->filter( m_provider->data() );
+    m_widgetFactory->setNoLinks( m_provider->realTimeIndexing() );
 
+    // Iterate through all remaining items embed the label
+    // and the value as new row in the widget
     int rowIndex = 0;
-    // Iterate through all remaining items.
-    // Embed the label and the value as new row in the widget
     const QStringList keys = sortedKeys(data);
-    const int spacerWidth = QFontMetrics(q->font()).size(Qt::TextSingleLine, QStringLiteral(" ")).width();
+    foreach (const QString& key, keys) {
+        const QVariant value = data[key];
+        QString itemLabel = m_provider->label(key);
+        itemLabel.append(QLatin1Char(':'));
 
-    const int labelColumn = m_configureVisibleProperties ? 1 : 0;
+        // Create label
+        QLabel* label = new QLabel(itemLabel, q);
+        label->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Preferred);
+        label->setForegroundRole(q->foregroundRole());
+        label->setFont(q->font());
+        label->setWordWrap(true);
+        label->setAlignment(Qt::AlignTop | Qt::AlignRight);
 
-    for (const auto& key : keys) {
-        Row row;
-        if (m_configureVisibleProperties) {
-            row.checkBox = new QCheckBox(q);
-            if (active.contains(key)) {
-                row.checkBox->setChecked(true);
-            }
-            m_gridLayout->addWidget(row.checkBox, rowIndex, 0, Qt::AlignTop | Qt::AlignRight);
-            connect(row.checkBox, &QCheckBox::stateChanged,
-                    q, [this, key](int state) { this->m_visibilityChanged[key] = (state == Qt::Checked); });
-        } else {
-            row.checkBox = nullptr;
-        }
+        // Create value-widget
+        QWidget* valueWidget = m_widgetFactory->createWidget(key, value, q);
 
-        row.label = createLabel(key, m_provider->label(key), q);
-        m_gridLayout->addWidget(row.label, rowIndex, labelColumn + 0, Qt::AlignRight);
-
-        m_gridLayout->addItem(new QSpacerItem(spacerWidth, 1), rowIndex, labelColumn + 1);
-
-        row.value = m_widgetFactory->createWidget(key, data[key], q);
-        m_gridLayout->addWidget(row.value, rowIndex, labelColumn + 2, Qt::AlignLeft);
-
-        m_gridLayout->setRowStretch(rowIndex, 0);
+        // Add the label and value-widget to grid layout
+        m_gridLayout->addWidget(label, rowIndex, 0, Qt::AlignRight);
+        const int spacerWidth = QFontMetrics(q->font()).size(Qt::TextSingleLine, " ").width();
+        m_gridLayout->addItem(new QSpacerItem(spacerWidth, 1), rowIndex, 1);
+        m_gridLayout->addWidget(valueWidget, rowIndex, 2, Qt::AlignLeft);
 
         // Remember the label and value-widget as row
+        Row row;
+        row.label = label;
+        row.value = valueWidget;
         m_rows.append(row);
+
         ++rowIndex;
     }
 
-    // Add vertical stretch - when the widget is embedded with extra vertical
-    // space, it should be added at the bottom, not distributed between the
-    // items.
-    m_gridLayout->addItem(new QSpacerItem(0, 0), rowIndex, 0, 1, -1);
-    m_gridLayout->setRowStretch(rowIndex, 1);
-
     q->updateGeometry();
     emit q->metaDataRequestFinished(m_provider->items());
 }
@@ -265,24 +212,6 @@ QStringList FileMetaDataWidget::Private::sortedKeys(const QVariantMap& data) con
     return list;
 }
 
-void FileMetaDataWidget::Private::saveConfig()
-{
-    if (m_visibilityChanged.isEmpty()) {
-        return;
-    }
-
-    KConfig config(QStringLiteral("baloofileinformationrc"), KConfig::NoGlobals);
-    KConfigGroup showGroup = config.group("Show");
-
-    auto changedIt = m_visibilityChanged.constBegin();
-    while (changedIt != m_visibilityChanged.constEnd()) {
-        showGroup.writeEntry(changedIt.key(), changedIt.value());
-        changedIt++;
-    }
-
-    showGroup.sync();
-}
-
 FileMetaDataWidget::FileMetaDataWidget(QWidget* parent)
     : QWidget(parent)
     , d(new Private(this))
@@ -296,8 +225,28 @@ FileMetaDataWidget::~FileMetaDataWidget()
 
 void FileMetaDataWidget::setItems(const KFileItemList& items)
 {
-    d->m_provider->setItems(items);
-    d->m_widgetFactory->setItems(items);
+    KFileItemList localItemsList;
+    QStringList list;
+
+    bool xAttrSuppored = true;
+
+    foreach(const KFileItem& item, items) {
+        QUrl url = item.targetUrl();
+        if (url.isLocalFile()) {
+            localItemsList << item;
+            QString path = url.toLocalFile();
+            list << path;
+
+            KFileMetaData::UserMetaData md(path);
+            xAttrSuppored &= md.isSupported();
+        }
+    }
+    setReadOnly(!xAttrSuppored);
+
+    d->m_provider->setItems(localItemsList);
+    d->m_widgetFactory->setItems(list);
+
+    setReadOnly(!xAttrSuppored);
 }
 
 KFileItemList FileMetaDataWidget::items() const
@@ -315,19 +264,10 @@ bool FileMetaDataWidget::isReadOnly() const
 {
     return d->m_provider->isReadOnly();
 }
-void FileMetaDataWidget::setDateFormat(const DateFormats format)
-{
-     d->m_widgetFactory->setDateFormat(format);
-}
-
-DateFormats FileMetaDataWidget::dateFormat() const
-{
-    return d->m_widgetFactory->dateFormat();
-}
 
 QSize FileMetaDataWidget::sizeHint() const
 {
-    if (d->m_gridLayout == nullptr) {
+    if (d->m_gridLayout == 0) {
         return QWidget::sizeHint();
     }
 
@@ -335,7 +275,7 @@ QSize FileMetaDataWidget::sizeHint() const
     int leftWidthMax = 0;
     int rightWidthMax = 0;
     int rightWidthAverage = 0;
-    for (const Private::Row& row : qAsConst(d->m_rows)) {
+    foreach (const Private::Row& row, d->m_rows) {
         const QWidget* valueWidget = row.value;
         const int rightWidth = valueWidget->sizeHint().width();
         rightWidthAverage += rightWidth;
@@ -361,7 +301,7 @@ QSize FileMetaDataWidget::sizeHint() const
 
     // Based on the available width calculate the required height
     int height = d->m_gridLayout->margin() * 2 + d->m_gridLayout->spacing() * (d->m_rows.count() - 1);
-    for (const Private::Row& row : qAsConst(d->m_rows)) {
+    foreach (const Private::Row& row, d->m_rows) {
         const QWidget* valueWidget = row.value;
         const int rowHeight = qMax(row.label->heightForWidth(leftWidthMax),
                                    valueWidget->heightForWidth(rightWidthMax));
@@ -374,18 +314,4 @@ QSize FileMetaDataWidget::sizeHint() const
     return QSize(width, height);
 }
 
-void FileMetaDataWidget::setConfigurationMode(ConfigurationMode mode)
-{
-    if (mode == ConfigurationMode::ReStart) {
-        d->m_configureVisibleProperties = true;
-    } else if (mode == ConfigurationMode::Accept) {
-        d->saveConfig();
-        d->m_configureVisibleProperties = false;
-    } else if (mode == ConfigurationMode::Cancel) {
-        d->m_configureVisibleProperties = false;
-    }
-    d->m_visibilityChanged.clear();
-    d->slotLoadingFinished();
-}
-
 #include "moc_filemetadatawidget.cpp"
