@@ -48,13 +48,13 @@ public:
     void setReadOnly(bool readOnly);
     bool isReadOnly() const;
     
-    virtual QSize sizeHint() const Q_DECL_OVERRIDE;
+    virtual QSize sizeHint() const;
 
 Q_SIGNALS:
     void commentChanged(const QString& comment);
 
 protected:
-    virtual bool event(QEvent* event) Q_DECL_OVERRIDE;
+    virtual bool event(QEvent* event);
 
 private Q_SLOTS:
     void slotLinkActivated(const QString& link);
