@@ -18,18 +18,17 @@
 #ifndef KEDIT_TAGS_DIALOG_H
 #define KEDIT_TAGS_DIALOG_H
 
-#include <QDialog>
-#include <QHash>
+#include <QtWidgets/QDialog>
 
 class QLineEdit;
 class KJob;
-class QTreeWidget;
-class QTreeWidgetItem;
+class QListWidget;
+class QListWidgetItem;
 class QPushButton;
 class QTimer;
 
 /**
- * @brief Dialog to edit a list of Baloo tags.
+ * @brief Dialog to edit a list of Nepomuk tags.
  *
  * It is possible for the user to add existing tags,
  * create new tags or to remove tags.
@@ -41,10 +40,10 @@ class KEditTagsDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit KEditTagsDialog(const QStringList& tags,
-                             QWidget* parent = nullptr);
+    KEditTagsDialog(const QStringList& tags,
+                    QWidget* parent = 0);
 
-    ~KEditTagsDialog() override;
+    virtual ~KEditTagsDialog();
 
     QStringList tags() const;
 
@@ -53,19 +52,19 @@ private Q_SLOTS:
     void slotAcceptedButtonClicked();
 
 
-    void slotItemActivated(const QTreeWidgetItem* item, int column);
+    void slotTagsLoaded(KJob* job);
 
 private:
-    void loadTagWidget();
-    void modifyTagWidget(const QString& tag);
+    void loadTags();
+    void removeNewTagItem();
 
 private:
-    QHash<QString, QTreeWidgetItem*> m_allTagTreeItems;
     QStringList m_tags;
     QStringList m_allTags;
-    QString m_newTag;
 
-    QTreeWidget* m_tagTree;
+    QListWidget* m_tagsList;
+    QListWidgetItem* m_newTagItem;
+    QListWidgetItem* m_autoCheckedItem;
     QLineEdit* m_newTagEdit;
 };
 
