@@ -1,5 +1,5 @@
 /*
-   This file is part of the Baloo KDE project.
+   This file is part of the Nepomuk KDE project.
    Copyright (C) 2013 Vishesh Handa <me@vhanda.in>
    Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>
 
@@ -22,24 +22,24 @@
 
 #include "tagcheckbox.h"
 #include "tagwidget.h"
+#include "tagwidget_p.h"
 
-#include <QMouseEvent>
-#include <QHBoxLayout>
-#include <QLabel>
+#include <QtGui/QMouseEvent>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
 
 using namespace Baloo;
 
 TagCheckBox::TagCheckBox(const QString& tag, QWidget* parent)
     : QWidget( parent ),
-      m_label(nullptr),
+      m_label(0),
       m_tag(tag),
       m_urlHover(false)
 {
     QHBoxLayout* layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setMargin(0);
 
-    m_label = new QLabel(tag.split(QLatin1Char('/'), QString::SkipEmptyParts).last(), this);
-    m_label->setToolTip(tag);
+    m_label = new QLabel(tag, this);
     m_label->setMouseTracking(true);
     m_label->setTextFormat(Qt::PlainText);
     m_label->setForegroundRole(parent->foregroundRole());
