@@ -1,5 +1,5 @@
 /*
- * This file is part of the Baloo KDE project.
+ * This file is part of the Nepomuk KDE project.
  * Copyright (C) 2006-2010 Sebastian Trueg <trueg@kde.org>
  * Copyright (C) 2011-2013 Vishesh Handa <me@vhanda.in>
  *
@@ -28,9 +28,9 @@
 #include <KLocalizedString>
 #include <KJob>
 
-#include <QPushButton>
-#include <QBoxLayout>
-#include <QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QBoxLayout>
+#include <QtWidgets/QLabel>
 
 using namespace Baloo;
 
@@ -38,11 +38,11 @@ void TagWidgetPrivate::init( TagWidget* parent )
 {
     q = parent;
     m_readOnly = false;
-    m_showAllLinkLabel = nullptr;
-    m_editTagsDialog = nullptr;
+    m_showAllLinkLabel = 0;
+    m_editTagsDialog = 0;
 
     QGridLayout* mainLayout = new QGridLayout( q );
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setMargin(0);
     //TODO spacingHint should be declared. Old code  m_flowLayout = new KBlockLayout( 0, KDialog::spacingHint()*3 );
     m_flowLayout = new KBlockLayout( 0 );
     mainLayout->addLayout( m_flowLayout, 0, 0, 1, 2 );
@@ -61,12 +61,12 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
     qDeleteAll(m_checkBoxHash);
     m_checkBoxHash.clear();
 
-    for (const QString& tag : tags) {
+    foreach (const QString& tag, tags) {
         getTagCheckBox(tag);
     }
 
     delete m_showAllLinkLabel;
-    m_showAllLinkLabel = nullptr;
+    m_showAllLinkLabel = 0;
 
     if (m_readOnly && !tags.isEmpty()) {
         return;
@@ -75,14 +75,14 @@ void TagWidgetPrivate::buildTagHash(const QStringList& tags)
     m_showAllLinkLabel = new QLabel( q );
     m_flowLayout->addWidget( m_showAllLinkLabel );
     if (m_readOnly) {
-        m_showAllLinkLabel->setText(QStringLiteral("-"));
+        m_showAllLinkLabel->setText("-");
     }
     else {
         QFont f(q->font());
         f.setUnderline(true);
         m_showAllLinkLabel->setFont(f);
         m_showAllLinkLabel->setText( QLatin1String("<a href=\"add_tags\">") +
-                                        ( m_checkBoxHash.isEmpty() ? i18nc("@label", "Add...") : i18nc("@label", "Edit...") ) +
+                                        ( m_checkBoxHash.isEmpty() ? i18nc("@label", "Add Tags...") : i18nc("@label", "Change...") ) +
                                         QLatin1String("</a>") );
         q->connect( m_showAllLinkLabel, SIGNAL(linkActivated(QString)), SLOT(slotShowAll()) );
     }
@@ -185,6 +185,6 @@ void TagWidget::slotKEditTagDialogFinished(int result)
     }
 
     d->m_editTagsDialog->deleteLater();
-    d->m_editTagsDialog = nullptr;
+    d->m_editTagsDialog = 0;
 }
 
